@@ -1,5 +1,5 @@
 # SNMP::Info::Entity
-# $Id: Entity.pm,v 1.24 2009/06/12 22:24:25 maxbaker Exp $
+# $Id$
 #
 # Copyright (c) 2008 Max Baker changes from version 0.8 and beyond.
 #
@@ -41,7 +41,7 @@ use SNMP::Info;
 
 use vars qw/$VERSION %MIBS %FUNCS %GLOBALS %MUNGE/;
 
-$VERSION = '2.03_02';
+$VERSION = '2.07_001';
 
 %MIBS = ( 'ENTITY-MIB' => 'entPhysicalSerialNum' );
 
@@ -207,7 +207,7 @@ Human Friendly
 
 =item $entity->e_fru()
 
-BOOLEAN. Field Replaceable unit?
+BOOLEAN. Is a Field Replaceable unit?
 
 (C<entPhysicalFRU>)
 
