@@ -1,5 +1,5 @@
 # SNMP::Info::Layer2::HP - SNMP Interface to HP ProCurve Switches
-# $Id: HP.pm,v 1.53 2011/01/04 15:00:22 jeroenvi Exp $
+# $Id$
 #
 # Copyright (c) 2008-2009 Max Baker changes from version 0.8 and beyond.
 #
@@ -46,7 +46,7 @@ use SNMP::Info::CDP;
 
 use vars qw/$VERSION %GLOBALS %MIBS %FUNCS %PORTSTAT %MODEL_MAP %MUNGE/;
 
-$VERSION = '2.03_02';
+$VERSION = '2.07_001';
 
 %MIBS = (
     %SNMP::Info::Layer3::MIBS,
@@ -61,6 +61,7 @@ $VERSION = '2.03_02';
     'HP-ICF-CHASSIS' => 'hpicfSensorObjectId',
     'HP-ICF-BRIDGE'  => 'hpicfBridgeRstpForceVersion',
     'HP-ICF-POE-MIB' => 'hpicfPoePethPsePortCurrent',
+    'SEMI-MIB'       => 'hpHttpMgSerialNumber',
 );
 
 %GLOBALS = (
@@ -69,11 +70,13 @@ $VERSION = '2.03_02';
     %SNMP::Info::LLDP::GLOBALS,
     %SNMP::Info::CDP::GLOBALS,
     'serial1'      => 'entPhysicalSerialNum.1',
+    'serial2'      => 'hpHttpMgSerialNumber.0',
     'hp_cpu'       => 'hpSwitchCpuStat.0',
     'hp_mem_total' => 'hpGlobalMemTotalBytes.1',
     'mem_free'     => 'hpGlobalMemFreeBytes.1',
     'mem_used'     => 'hpGlobalMemAllocBytes.1',
     'os_version'   => 'hpSwitchOsVersion.0',
+    'os_version2'  => 'hpHttpMgVersion.0',
     'os_bin'       => 'hpSwitchRomVersion.0',
     'mac'          => 'hpSwitchBaseMACAddress.0',
     'rstp_ver'     => 'hpicfBridgeRstpForceVersion',
@@ -145,6 +148,15 @@ $VERSION = '2.03_02';
     'J8771A' => '4202vl-48G',
     'J4865A' => '4108GL',
     'J4887A' => '4104GL',
+    'J9588A' => '3800-48G-PoE+-4XG',
+    'J9574A' => '3800-48G-PoE+-4SFP+',
+    'J9586A' => '3800-48G-4XG',
+    'J9576A' => '3800-48G-4SFP+',
+    'J9584A' => '3800-24SFP-2SFP+',
+    'J9587A' => '3800-24G-PoE+-2XG',
+    'J9573A' => '3800-24G-PoE+-2SFP+',
+    'J9585A' => '3800-24G-2XG',
+    'J9575A' => '3800-24G-2SFP+',
     'J8693A' => '3500yl-48G-PWR',
     'J8692A' => '3500yl-24G-PWR',
     'J9473A' => '3500-48-PoE',
@@ -174,6 +186,11 @@ $VERSION = '2.03_02';
     'J4900B' => '2626-CR',
     'J4900C' => '2626C',
     'J4900A' => '2626',
+    'J9627A' => '2620-48-PoE+',
+    'J9624A' => '2620-48',
+    'J9624A' => '2620-24-PPoE+',
+    'J9625A' => '2620-24-PoE+',
+    'J9623A' => '2620-24',
     'J9565A' => '2615-8-PoE',
     'J9089A' => '2610-48-PWR',
     'J9088A' => '2610-48',
@@ -182,10 +199,10 @@ $VERSION = '2.03_02';
     'J9085A' => '2610-24',
     'J8762A' => '2600-8-PWR',
     'J4813A' => '2524',
-    'J9137A' => '2520-8-PoE',
-    'J9138A' => '2520-24-PoE',
     'J9298A' => '2520G-8-PoE',
     'J9299A' => '2520G-24-PoE',
+    'J9137A' => '2520-8-PoE',
+    'J9138A' => '2520-24-PoE',
     'J4812A' => '2512',
     'J9280A' => '2510G-48',
     'J9279A' => '2510G-24',
@@ -223,7 +240,7 @@ sub os {
 
 sub os_ver {
     my $hp         = shift;
-    my $os_version = $hp->os_version();
+    my $os_version = $hp->os_version() || $hp->os_version2();
     return $os_version if defined $os_version;
 
     # Some older ones don't have this value,so we cull it from the description
@@ -234,6 +251,16 @@ sub os_ver {
     return;
 }
 
+# Regular managed ProCurve switches have the serial num in entity mib, 
+# the web-managed models in the semi mib (hphttpmanageable).
+sub serial {
+    my $hp = shift;
+
+    my $serial = $hp->serial1() || $hp->serial2() || undef;;
+
+    return $serial;
+}
+
 # Lookup model number, and translate the part number to the common number
 sub model {
     my $hp = shift;
@@ -612,6 +639,7 @@ sub set_i_vlan_tagged {
             $hp->error_throw(sprintf("Requested VLAN %s doesn't seem to exist on device...", $vlan));
         }
     }
+    return;
 }
 
 1;
@@ -761,6 +789,15 @@ number and the common model number with this map :
     'J8771A' => '4202vl-48G',
     'J4865A' => '4108GL',
     'J4887A' => '4104GL',
+    'J9588A' => '3800-48G-PoE+-4XG',
+    'J9574A' => '3800-48G-PoE+-4SFP+',
+    'J9586A' => '3800-48G-4XG',
+    'J9576A' => '3800-48G-4SFP+',
+    'J9584A' => '3800-24SFP-2SFP+',
+    'J9587A' => '3800-24G-PoE+-2XG',
+    'J9573A' => '3800-24G-PoE+-2SFP+',
+    'J9585A' => '3800-24G-2XG',
+    'J9575A' => '3800-24G-2SFP+',
     'J8693A' => '3500yl-48G-PWR',
     'J8692A' => '3500yl-24G-PWR',
     'J9473A' => '3500-48-PoE',
@@ -771,6 +808,7 @@ number and the common model number with this map :
     'J4905A' => '3400cl-24G',
     'J4815A' => '3324XL',
     'J4851A' => '3124',
+    'J9562A' => '2915-8G-PoE',
     'J9148A' => '2910al-48G-PoE+',
     'J9147A' => '2910al-48G',
     'J9146A' => '2910al-24G-PoE+',
@@ -789,6 +827,12 @@ number and the common model number with this map :
     'J4900B' => '2626-CR',
     'J4900C' => '2626C',
     'J4900A' => '2626',
+    'J9627A' => '2620-48-PoE+',
+    'J9624A' => '2620-48',
+    'J9624A' => '2620-24-PPoE+',
+    'J9625A' => '2620-24-PoE+',
+    'J9623A' => '2620-24',
+    'J9565A' => '2615-8-PoE',
     'J9089A' => '2610-48-PWR',
     'J9088A' => '2610-48',
     'J9087A' => '2610-24-PWR',
@@ -796,6 +840,8 @@ number and the common model number with this map :
     'J9085A' => '2610-24',
     'J8762A' => '2600-8-PWR',
     'J4813A' => '2524',
+    'J9298A' => '2520G-8-PoE',
+    'J9299A' => '2520G-24-PoE',
     'J9137A' => '2520-8-PoE',
     'J9138A' => '2520-24-PoE',
     'J4812A' => '2512',
@@ -806,6 +852,8 @@ number and the common model number with this map :
     'J9019A' => '2510-24A',
     'J4818A' => '2324',
     'J4817A' => '2312',
+    'J9449A' => '1810G-8',
+    'J9450A' => '1810G-24',
     'J9029A' => '1800-8G',
     'J9028A' => '1800-24G',
 );
@@ -827,6 +875,10 @@ the description field.
 
 C<hpSwitchOsVersion.0>
 
+=item $hp->serial()
+
+Returns serial number if available through SNMP
+
 =item $hp->slots()
 
 Returns number of entries in $hp->e_name that have 'slot' in them.
