@@ -1,5 +1,5 @@
 # SNMP::Info::Layer3 - SNMP Interface to Layer3 devices
-# $Id: Layer3.pm,v 1.38 2010/10/21 10:29:57 jeroenvi Exp $
+# $Id$
 #
 # Copyright (c) 2008 Max Baker -- All changes from Version 0.7 on
 #
@@ -39,25 +39,28 @@ use SNMP::Info::Bridge;
 use SNMP::Info::EtherLike;
 use SNMP::Info::Entity;
 use SNMP::Info::PowerEthernet;
-use SNMP::Info::Ipv6;
+use SNMP::Info::IPv6;
+use SNMP::Info::AdslLine;
 
 @SNMP::Info::Layer3::ISA = qw/
-    SNMP::Info::PowerEthernet SNMP::Info::Ipv6
+    SNMP::Info::PowerEthernet SNMP::Info::IPv6
     SNMP::Info::Entity SNMP::Info::EtherLike
-    SNMP::Info::Bridge SNMP::Info Exporter/;
+    SNMP::Info::Bridge SNMP::Info::AdslLine
+    SNMP::Info Exporter/;
 @SNMP::Info::Layer3::EXPORT_OK = qw//;
 
 use vars qw/$VERSION %GLOBALS %FUNCS %MIBS %MUNGE/;
 
-$VERSION = '2.03_02';
+$VERSION = '2.07_001';
 
 %MIBS = (
     %SNMP::Info::MIBS,
+    %SNMP::Info::AdslLine::MIBS,
     %SNMP::Info::Bridge::MIBS,
     %SNMP::Info::EtherLike::MIBS,
     %SNMP::Info::Entity::MIBS,
     %SNMP::Info::PowerEthernet::MIBS,
-    %SNMP::Info::Ipv6::MIBS,
+    %SNMP::Info::IPv6::MIBS,
     'IP-MIB'   => 'ipNetToMediaIfIndex',
     'OSPF-MIB' => 'ospfRouterId',
     'BGP4-MIB' => 'bgpIdentifier',
@@ -67,11 +70,12 @@ $VERSION = '2.03_02';
 
     # Inherit the super class ones
     %SNMP::Info::GLOBALS,
+    %SNMP::Info::AdslLine::GLOBALS,
     %SNMP::Info::Bridge::GLOBALS,
     %SNMP::Info::EtherLike::GLOBALS,
     %SNMP::Info::Entity::GLOBALS,
     %SNMP::Info::PowerEthernet::GLOBALS,
-    %SNMP::Info::Ipv6::GLOBALS,
+    %SNMP::Info::IPv6::GLOBALS,
     'mac' => 'ifPhysAddress.1',
     'serial1' =>
         '.1.3.6.1.4.1.9.3.6.3.0',    # OLD-CISCO-CHASSIS-MIB::chassisId.0
@@ -82,11 +86,12 @@ $VERSION = '2.03_02';
 
 %FUNCS = (
     %SNMP::Info::FUNCS,
+    %SNMP::Info::AdslLine::FUNCS,
     %SNMP::Info::Bridge::FUNCS,
     %SNMP::Info::EtherLike::FUNCS,
     %SNMP::Info::Entity::FUNCS,
     %SNMP::Info::PowerEthernet::FUNCS,
-    %SNMP::Info::Ipv6::FUNCS,
+    %SNMP::Info::IPv6::FUNCS,
 
     # Obsolete Address Translation Table (ARP Cache)
     'old_at_index'   => 'atIfIndex',
@@ -127,9 +132,6 @@ $VERSION = '2.03_02';
     'bgp_peer_out_upd'        => 'bgpPeerOutUpdates',
 
     # IP-MIB Net to Physical Table (ARP Cache)
-    'n2p_index' => 'ipNetToPhysicalIfIndex',
-    'n2p_naddrt' => 'ipNetToPhysicalNetAddressType',
-    'n2p_naddr' => 'ipNetToPhysicalNetAddress',
     'n2p_paddr' => 'ipNetToPhysicalPhysAddress',
     'n2p_lastupdate' => 'ipNetToPhysicalLastUpdated',
     'n2p_ptype' => 'ipNetToPhysicalType',
@@ -142,11 +144,12 @@ $VERSION = '2.03_02';
 
     # Inherit all the built in munging
     %SNMP::Info::MUNGE,
+    %SNMP::Info::AdslLine::MUNGE,
     %SNMP::Info::Bridge::MUNGE,
     %SNMP::Info::EtherLike::MUNGE,
     %SNMP::Info::Entity::MUNGE,
     %SNMP::Info::PowerEthernet::MUNGE,
-    %SNMP::Info::Ipv6::MUNGE,
+    %SNMP::Info::IPv6::MUNGE,
     'old_at_paddr' => \&SNMP::Info::munge_mac,
     'at_paddr'     => \&SNMP::Info::munge_mac,
     'n2p_paddr' => \&SNMP::Info::munge_mac,
@@ -160,6 +163,14 @@ sub root_ip {
     my $router_ip = $l3->router_ip();
     my $ospf_ip   = $l3->ospf_ip();
 
+    # if the router ip exists and is a route advertised by the device we prefer
+    # it over the others
+    return $router_ip
+        if (( defined $router_ip )
+        and ( $router_ip ne '0.0.0.0' )
+        and ( grep { $ospf_ip->{$_} eq $router_ip } (keys %$ospf_ip))
+        and ( $l3->snmp_connect_ip($router_ip) ) );
+
     # return the first one found here (should be only one)
     if ( defined $ospf_ip and scalar( keys %$ospf_ip ) ) {
         foreach my $key ( keys %$ospf_ip ) {
@@ -171,10 +182,6 @@ sub root_ip {
         }
     }
 
-    return $router_ip
-        if (( defined $router_ip )
-        and ( $router_ip ne '0.0.0.0' )
-        and ( $l3->snmp_connect_ip($router_ip) ) );
     return;
 }
 
@@ -405,7 +412,7 @@ after determining a more specific class using the method above.
 
 =item SNMP::Info::PowerEthernet
 
-=item SNMP::Info::Ipv6
+=item SNMP::Info::IPv6
 
 =back
 
@@ -433,7 +440,7 @@ See L<SNMP::Info::Entity/"Required MIBs"> for its MIB requirements.
 
 See L<SNMP::Info::PowerEthernet/"Required MIBs"> for its MIB requirements.
 
-See L<SNMP::Info::Ipv6/"Required MIBs"> for its MIB requirements.
+See L<SNMP::Info::IPv6/"Required MIBs"> for its MIB requirements.
 
 =head1 GLOBALS
 
@@ -779,8 +786,8 @@ See L<SNMP::Info::Entity/"TABLE METHODS"> for details.
 
 See L<SNMP::Info::PowerEthernet/"TABLE METHODS"> for details.
 
-=head2 Table Methods imported from SNMP::Info::Ipv6
+=head2 Table Methods imported from SNMP::Info::IPv6
 
-See L<SNMP::Info::Ipv6/"TABLE METHODS"> for details.
+See L<SNMP::Info::IPv6/"TABLE METHODS"> for details.
 
 =cut
