@@ -1,5 +1,5 @@
 # SNMP::Info::Layer3::Enterasys - SNMP Interface to Enterasys devices
-# $Id: Enterasys.pm,v 1.12 2009/06/12 22:24:25 maxbaker Exp $
+# $Id$
 #
 # Copyright (c) 2008 Eric Miller
 # All rights reserved.
@@ -44,7 +44,7 @@ use SNMP::Info::Layer3;
 
 use vars qw/$VERSION $DEBUG %GLOBALS %FUNCS $INIT %MIBS %MUNGE/;
 
-$VERSION = '2.03_02';
+$VERSION = '2.07_001';
 
 %MIBS = (
     %SNMP::Info::Layer3::MIBS, %SNMP::Info::CDP::MIBS,
@@ -166,12 +166,6 @@ sub fw_port {
 }
 
 #  Use CDP and/or LLDP
-#
-#  LLDP table timefilter implementation continuously increments when walked
-#  and we may never reach the end of the table.  This behavior can be
-#  modified with the "set snmp timefilter break disable" command,
-#  unfortunately it is not the default.  Query with a partial value of zero
-#  which means no time filter.
 
 sub hasCDP {
     my $enterasys = shift;
@@ -184,7 +178,7 @@ sub c_ip {
     my $partial   = shift;
 
     my $cdp  = $enterasys->SUPER::c_ip($partial) || {};
-    my $lldp = $enterasys->lldp_ip(0)            || {};
+    my $lldp = $enterasys->lldp_ip($partial)     || {};
 
     my %c_ip;
     foreach my $iid ( keys %$cdp ) {
@@ -207,7 +201,7 @@ sub c_if {
     my $enterasys = shift;
     my $partial   = shift;
 
-    my $lldp = $enterasys->lldp_if(0)            || {};
+    my $lldp = $enterasys->lldp_if($partial)     || {};
     my $cdp  = $enterasys->SUPER::c_if($partial) || {};
 
     my %c_if;
@@ -231,7 +225,7 @@ sub c_port {
     my $enterasys = shift;
     my $partial   = shift;
 
-    my $lldp = $enterasys->lldp_port(0)            || {};
+    my $lldp = $enterasys->lldp_port($partial)     || {};
     my $cdp  = $enterasys->SUPER::c_port($partial) || {};
 
     my %c_port;
@@ -255,7 +249,7 @@ sub c_id {
     my $enterasys = shift;
     my $partial   = shift;
 
-    my $lldp = $enterasys->lldp_id(0)            || {};
+    my $lldp = $enterasys->lldp_id($partial)     || {};
     my $cdp  = $enterasys->SUPER::c_id($partial) || {};
 
     my %c_id;
@@ -279,7 +273,7 @@ sub c_platform {
     my $enterasys = shift;
     my $partial   = shift;
 
-    my $lldp = $enterasys->lldp_rem_sysdesc(0)         || {};
+    my $lldp = $enterasys->lldp_rem_sysdesc($partial)  || {};
     my $cdp  = $enterasys->SUPER::c_platform($partial) || {};
 
     my %c_platform;
